package com.ruoyi.tuya.mapper;

import java.util.List;
import com.ruoyi.tuya.domain.TuyaArticleInfo;
import com.ruoyi.tuya.domain.TuyaSitesInfo;

/**
 * 内容信息Mapper接口
 *
 * @author ruoyi
 * @date 2022-07-14
 */
public interface TuyaArticleInfoMapper
{
    /**
     * 校验内容名称
     *
     * @param tuyaArticleInfo 内容信息
     * @return 结果
     */
    public TuyaArticleInfo checkArticleTitleUnique(TuyaArticleInfo tuyaArticleInfo);

    /**
     * 查询内容信息
     *
     * @param articleId 内容信息主键
     * @return 内容信息
     */
    public TuyaArticleInfo selectTuyaArticleInfoByArticleId(Long articleId);

    /**
     * 查询内容信息列表
     *
     * @param tuyaArticleInfo 内容信息
     * @return 内容信息集合
     */
    public List<TuyaArticleInfo> selectTuyaArticleInfoList(TuyaArticleInfo tuyaArticleInfo);

    /**
     * 新增内容信息
     *
     * @param tuyaArticleInfo 内容信息
     * @return 结果
     */
    public int insertTuyaArticleInfo(TuyaArticleInfo tuyaArticleInfo);

    /**
     * 修改内容信息
     *
     * @param tuyaArticleInfo 内容信息
     * @return 结果
     */
    public int updateTuyaArticleInfo(TuyaArticleInfo tuyaArticleInfo);

    /**
     * 删除内容信息
     *
     * @param articleId 内容信息主键
     * @return 结果
     */
    public int deleteTuyaArticleInfoByArticleId(Long articleId);

    /**
     * 批量删除内容信息
     *
     * @param articleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTuyaArticleInfoByArticleIds(Long[] articleIds);
}
