package com.ruoyi.tuya.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.constant.UserConstants;
import com.ruoyi.tuya.domain.TuyaArticleInfo;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.tuya.service.ITuyaArticleInfoService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 内容信息Controller
 *
 * @author ruoyi
 * @date 2022-07-14
 */
@RestController
@RequestMapping("/tuya/articleinfo")
public class TuyaArticleInfoController extends BaseController
{
    @Autowired
    private ITuyaArticleInfoService tuyaArticleInfoService;

    /**
     * 查询内容信息列表
     */
    @PreAuthorize("@ss.hasPermi('tuya:articleinfo:list')")
    @GetMapping("/list")
    public TableDataInfo list(TuyaArticleInfo tuyaArticleInfo)
    {
        startPage();
        List<TuyaArticleInfo> list = tuyaArticleInfoService.selectTuyaArticleInfoList(tuyaArticleInfo);
        return getDataTable(list);
    }

    /**
     * 导出内容信息列表
     */
    @PreAuthorize("@ss.hasPermi('tuya:articleinfo:export')")
    @Log(title = "内容信息", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TuyaArticleInfo tuyaArticleInfo)
    {
        List<TuyaArticleInfo> list = tuyaArticleInfoService.selectTuyaArticleInfoList(tuyaArticleInfo);
        ExcelUtil<TuyaArticleInfo> util = new ExcelUtil<TuyaArticleInfo>(TuyaArticleInfo.class);
        util.exportExcel(response, list, "内容信息数据");
    }

    /**
     * 获取内容信息详细信息
     */
    @PreAuthorize("@ss.hasPermi('tuya:articleinfo:query')")
    @GetMapping(value = "/{articleId}")
    public AjaxResult getInfo(@PathVariable("articleId") Long articleId)
    {
        return AjaxResult.success(tuyaArticleInfoService.selectTuyaArticleInfoByArticleId(articleId));
    }

    /**
     * 新增内容信息
     */
    @PreAuthorize("@ss.hasPermi('tuya:articleinfo:add')")
    @Log(title = "内容信息", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody TuyaArticleInfo tuyaArticleInfo)
    {
        if (UserConstants.NOT_UNIQUE.equals(tuyaArticleInfoService.checkArticleTitleUnique(tuyaArticleInfo)))
        {
            return AjaxResult.error("新增内容'" + tuyaArticleInfo.getArticleTitle() + "'失败，内容标题已存在");
        }
        tuyaArticleInfo.setCreateBy(getUsername());
        return toAjax(tuyaArticleInfoService.insertTuyaArticleInfo(tuyaArticleInfo));
    }

    /**
     * 修改内容信息
     */
    @PreAuthorize("@ss.hasPermi('tuya:articleinfo:edit')")
    @Log(title = "内容信息", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody TuyaArticleInfo tuyaArticleInfo)
    {
        if (UserConstants.NOT_UNIQUE.equals(tuyaArticleInfoService.checkArticleTitleUnique(tuyaArticleInfo)))
        {
            return AjaxResult.error("修改内容'" + tuyaArticleInfo.getArticleTitle() + "'失败，内容标题已存在");
        }
        tuyaArticleInfo.setUpdateBy(getUsername());
        return toAjax(tuyaArticleInfoService.updateTuyaArticleInfo(tuyaArticleInfo));
    }

    /**
     * 删除内容信息
     */
    @PreAuthorize("@ss.hasPermi('tuya:articleinfo:remove')")
    @Log(title = "内容信息", businessType = BusinessType.DELETE)
	@DeleteMapping("/{articleIds}")
    public AjaxResult remove(@PathVariable Long[] articleIds)
    {
        return toAjax(tuyaArticleInfoService.deleteTuyaArticleInfoByArticleIds(articleIds));
    }
}
